@@ -148,11 +148,9 @@ impl Machine<Building, ClientBuildingState> {
             ..
         } = self.state;
 
-        #[allow(unused_mut)]
         let mut conn = conn.update_state();
 
-        #[cfg(test)]
-        assert!(conn.bytes_left().await == 0);
+        super::assert_conn_empty(&mut conn).await;
 
         super::built::ClientBuiltState {
             conn,
@@ -170,11 +168,10 @@ impl Machine<Building, ClientBuildingState> {
             ..
         } = self.state;
 
-        #[allow(unused_mut)]
         let mut conn = conn.update_state();
 
-        #[cfg(test)]
-        assert!(conn.bytes_left().await == 0);
+        super::assert_conn_empty(&mut conn).await;
+
         super::prepare_build::ClientPrepareBuildState {
             conn,
             working_dir,
@@ -256,11 +253,9 @@ impl Machine<Building, ServerBuildingState> {
             batch_name,
             job_identifier,
         } = self.state;
-        #[allow(unused_mut)]
-        let mut conn = conn.update_state();
 
-        #[cfg(test)]
-        assert!(conn.bytes_left().await == 0);
+        let mut conn = conn.update_state();
+        super::assert_conn_empty(&mut conn).await;
 
         super::built::ServerBuiltState {
             conn,
@@ -279,11 +274,10 @@ impl Machine<Building, ServerBuildingState> {
 
         let ServerBuildingState { conn, common, .. } = self.state;
 
-        #[allow(unused_mut)]
         let mut conn = conn.update_state();
 
-        #[cfg(test)]
-        assert!(conn.bytes_left().await == 0);
+        super::assert_conn_empty(&mut conn).await;
+
         super::prepare_build::ServerPrepareBuildState { conn, common }
     }
 }
